==> asdf_standard-1.0.0.tar.gz: asdf_standard-1.0.0/README.md <==
ASDF standard 1.6.0
===================
![CI](https://github.com/asdf-format/asdf-standard/workflows/CI/badge.svg)

This document describes the Advanced Scientific Data Format (ASDF),
pronounced *AZ*-diff.  You can read the full specification at [the online documentation](http://asdf-standard.readthedocs.io/).

> This is the **A**dvanced **S**cientific **D**ata **F**ormat - if you are looking for the **A**daptable **S**eismic **D**ata **F**ormat, go here: http://seismic-data.org/


## Contributing
Please open a new [issue](https://github.com/spacetelescope/asdf-standard/issue) or new [pull request](https://github.com/spacetelescope/asdf-standard/pulls) for bugs, feedback, or new features you would like to see. If there is an issue you would like to work on, please leave a comment and we will be happy to assist. New contributions and contributors are very welcome!

There are two mailing lists for ASDF:

* [asdf-users](https://groups.google.com/forum/#!forum/asdf-users)
* [asdf-developers](https://groups.google.com/forum/#!forum/asdf-developers)

## Getting More Information

* [FAQ page](https://github.com/spacetelescope/asdf-standard/wiki/FAQ) on the wiki.
* [ASDF: A new data format for astronomy](https://doi.org/10.1016/j.ascom.2015.06.004), published in *Astronomy and Computing*:

> Greenfield, P., Droettboom, M., & Bray, E. (2015). ASDF: A new data format for astronomy. *Astronomy and Computing*, 12: 240-251.
> doi:[10.1016/j.ascom.2015.06.004](https://doi.org/10.1016/j.ascom.2015.06.004)

==> asdf_standard-1.0.1.tar.gz: asdf_standard-1.0.1/README.md <==
ASDF standard 1.6.0
===================
![CI](https://github.com/asdf-format/asdf-standard/workflows/CI/badge.svg)
[![pre-commit](https://img.shields.io/badge/pre--commit-enabled-brightgreen?logo=pre-commit&logoColor=white)](https://github.com/pre-commit/pre-commit)
[![Code style: black](https://img.shields.io/badge/code%20style-black-000000.svg)](https://github.com/psf/black)
[![Imports: isort](https://img.shields.io/badge/%20imports-isort-%231674b1?style=flat&labelColor=ef8336)](https://pycqa.github.io/isort/)

This document describes the Advanced Scientific Data Format (ASDF),
pronounced *AZ*-diff.  You can read the full specification at [the online documentation](http://asdf-standard.readthedocs.io/).

> This is the **A**dvanced **S**cientific **D**ata **F**ormat - if you are looking for the **A**daptable **S**eismic **D**ata **F**ormat, go here: http://seismic-data.org/


## Contributing
Please open a new [issue](https://github.com/spacetelescope/asdf-standard/issue) or new [pull request](https://github.com/spacetelescope/asdf-standard/pulls) for bugs, feedback, or new features you would like to see. If there is an issue you would like to work on, please leave a comment and we will be happy to assist. New contributions and contributors are very welcome!

There are two mailing lists for ASDF:

* [asdf-users](https://groups.google.com/forum/#!forum/asdf-users)
* [asdf-developers](https://groups.google.com/forum/#!forum/asdf-developers)

## Getting More Information

* [FAQ page](https://github.com/spacetelescope/asdf-standard/wiki/FAQ) on the wiki.
* [ASDF: A new data format for astronomy](https://doi.org/10.1016/j.ascom.2015.06.004), published in *Astronomy and Computing*:

> Greenfield, P., Droettboom, M., & Bray, E. (2015). ASDF: A new data format for astronomy. *Astronomy and Computing*, 12: 240-251.
> doi:[10.1016/j.ascom.2015.06.004](https://doi.org/10.1016/j.ascom.2015.06.004)
